# API Documentation of Bash Base Library

## Error Messages

### error-codes

```
error-codes (bash-crypto)
# <50 .. reserved for base-base error-codes
#  9x .. errors local to each function
```

## base32 en/decoding

### bcr_digest_read

```
bcr_digest_read <ret-vn> <digest>
# runs a digest against input data read from stdin
# where digest can be: md5|sha(1|224|256|384|512)|ripemd160|whirlpool
# errors: 2, 3, 4, 91 (openssl not found), 92 (openssl error)
```

### bcr_digest_of_hex

```
bcr_digest_of_hex <ret-vn> <digest> <hex-message>
# runs a digest against a hex encoded message
# where digest can be: md5|sha(1|224|256|384|512)|ripemd160|whirlpool
# errors: 2, 3, 4, 91 (openssl not found), 92 (openssl error)
```

### bcr_base32_encode_of_hex

```
bcr_base32_encode_of_hex <ret-vn> <hex> [default|exthex|bech32]
# encodes hex representation of binary data to base32 string
# https://tools.ietf.org/html/rfc4648
# note: bech32 is untested
# errors: 2, 3, 91 (illegal char in hex), 92 (hex is of odd length)
```

## HMAC (RFC 2104)

### bcr_hmac

```
bcr_hmac <ret-vn> <digest> <hex-key> <hex-data>
# where digest is one of: md5|sha(1|224|256|384|512)|ripemd160|whirlpool
# computes hmac defined in https://tools.ietf.org/html/rfc2104
# errors: 2, 3, 4, 91 (illegal char in hex), 92 (hex is of odd length)
```
